def penjumlahan(num1, num2):
    return num1 + num2

def pengurangan(num1, num2):
    return num1 - num2

def perkalian(num1, num2):
    return num1 * num2

def pembagian(num1, num2):
    return num1 / num2